OC.L10N.register(
    "logreader",
    {
    "Logging" : "Уписивање у дневник",
    "Errors in the log" : "Грешке у дневнику",
    "No errors in the logs since %s" : "У дневнику нема грешака од %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["У дневнику има %n грешка од %s","У дневнику има %n грешке од %s","У дневнику има %n грешака од %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["У дневнику има %n упозорење од %s","У дневнику има %n упозорења од %s","У дневнику има %n упозорења од %s"],
    "Log Reader" : "Читач дневника",
    "A log reader for Nextcloud" : "Читач дневника за Некстклауд",
    "Log reader for Nextcloud" : "Читач дневника за Некстклауд",
    "Log reader" : "Читач дневника",
    "Open log reader settings" : "Отвори поставке читача дневника",
    "Log reader settings" : "Поставке читача дневника",
    "Currently the log file {file} is shown" : "Тренутно се приказује фајл дневника {file}",
    "Show server log" : "Прикажи дневник сервера",
    "Live view is disabled" : "Искључен је приказ уживо",
    "No log file" : "Нема фајла дневника",
    "File-based logging must be enabled to access logs from the Web UI." : "Да би се приступило дневницима из Веб КИ, потребно је да се укључи логовање засновано на фајловима.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Ако сматрате да је ово грешка, молимо вас да проверите {setting} у {config} и да консултујете Nextcloud упутство за администрацију.",
    "Level" : "Ниво",
    "App" : "Апликација",
    "No app in context" : "Нема апликације у контексту",
    "Time" : "Време",
    "Copy raw entry" : "Копирај сирову ставку",
    "Copy formatted entry" : "Копирај форматирану ставку",
    "Hide exception details" : "Сакриј детаље изузетка",
    "View exception details" : "Прикажи детаље изузетка",
    "Raw log entry" : "Сирова ставка дневника",
    "Log entry successfully copied" : "Успешно је копирана ставка дневника",
    "Search log entries" : "Претражи ставке дневника",
    "Caused by {exception}" : "Изазвао је {exception}",
    "Line {line}" : "Линија {line}",
    "Filter log levels" : "Филтрирај нивое дневника",
    "Set log level" : "Постави ниво уписа у дневник",
    "Time format" : "Формат времена",
    "Live view" : "Приказ уживо",
    "Download/Upload logs" : "Преузми/Отпреми дневнике",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Такође можете да прикажете ис тавке дневника копиране у клипборд тако што их налепите у приказ дневника користећи: {keyboardShortcut}",
    "Download logs" : "Скини дневнике",
    "Show local log file" : "Прикажи локални фајл дневника",
    "Upload local log file to be displayed" : "Отпреми локални фајл дневника који треба да се прикаже",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Не може да се парсира фајл локалног дневника",
    "Raw data" : "Сирови подаци",
    "Local time" : "Локално време",
    "UTC time" : "UTC време",
    "Time format used for displaying the timestamp" : "Формат времена који се користи за приказ временске ознаке",
    "(Local log files only support the \"raw\" time format)" : "(Локални фајлови дневника подржавају само „raw” формат времена)",
    "Could not change date time format." : "Не може да се промени формат датума и времена.",
    "Polling is disabled because server is not configured to log to file" : "Полирање је искључено јер сервер није подешен тако да дневник уписује у фајл",
    "Polling (live view)" : "Полирање (приказ уживо)",
    "Could not change live view setting." : "Не може да се промени подешавања приказа уживо.",
    "Filter logging levels" : "Филтрирај нивое белеђења дневника",
    "Could not set logging levels to show" : "Нису могли да се поставе нивои бележења дневника који се приказују",
    "Set backend loglevel" : "Постави ниво уписа у дневник позадинског механизма",
    "Could not set logging level" : "Није могао да се постави ниво уписа у дневник",
    "Application" : "Апликација",
    "Message" : "Порука",
    "Log entry actions" : "Акције ставке дневника",
    "Loading older log entries" : "Учитавање старијих ставки дневника",
    "No older log entries available" : "Нема старијих ставки дневника",
    "Collapse row" : "Сажми ред",
    "Expand row" : "Прошири ред",
    "Show details" : "Прикажи детаље",
    "Debug" : "Дибаг",
    "Info" : "Инфо",
    "Warning" : "Упозорење",
    "Error" : "Грешка",
    "Fatal" : "Фатално",
    "Could not load log entries" : "Нису могле да се учитају ставке дневника",
    "Clipboard" : "Клипборд",
    "Could not parse clipboard content" : "Не може да се парсира садржај клипборда",
    "Could not fetch new log entries (server unavailable)" : "Не могу да се прибаве нове ставке дневника (сервер није доступан)",
    "Could not fetch new entries" : "Не могу да се добаве нове ставке",
    "Could not copy to clipboard, please copy manually:" : "Не може да се копира у клипборд, молимо вас да ручно копирате:",
    "\tfrom {address} by {user} at {time}\n" : "\tиз {address} {user} у {time}\n",
    "Error parsing log" : "Грешка при парсирању дневника",
    "Caused by " : "Изазвао",
    "Copy" : "Копирај",
    "Copy raw" : "Копирај непрерађено",
    "Copy formatted" : "Копирај форматирано",
    "No server logs" : "Нема дневника на серверу",
    "One or more entries are hidden by the log level filter" : "Један или више уноса су скривени због нивоа филтрирања",
    "Everything is working fine" : "Све ради лепо",
    "Load log file" : "Учитај фајл дневника",
    "Invalid log file" : "Неисправан фајл дневника",
    "Log levels" : "Нивои логовања",
    "Log content" : "Садржај дневника",
    "Live update" : "Ажурирање уживо",
    "line {line}" : "линија {line}",
    "Download / Upload logs" : "Преузми / Отпреми дневнике"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
